@@ -73,7 +73,7 @@ class DlgConfig:
       labelid = QtGui.QLabel()
       labelid.setText("Num. de mobile")
       self.login = QtGui.QLineEdit()
-      hLayout.addWidget(labelid)
+      hLayout.addWidget(labelid) 
       hLayout.addWidget(self.login)
       
       hLayout2 = QtGui.QHBoxLayout()
@@ -91,12 +91,19 @@ class DlgConfig:
       
       operators = [('Bouygues Telecom', 'bouygues.png'),
                    ('SFR', 'sfr.png'),
-#                   ('Orange', 'orange.png')
+                   # ('Orange', 'orange.png'),
+                   #('Universal Mobile', 'universal-music-mobile.png'),
+                   # ('Virgin Mobile', 'virginmobile.png'),
+                   # ('Carrefour Mobile', 'carrefourmobile.png'),
+                   # ('M6 Mobile', 'm6mobile.png'),
                    ]
 
-      iconPath = '/opt/qonso/icons'
+      iconPath = 'icons'
       if not os.path.exists(iconPath):
-         iconPath = 'icons'
+         iconPath = 'MyDocs/Dev/Qonso/src/opt/qonso/icons'
+
+      if not os.path.exists(iconPath):
+         iconPath = '/opt/qonso/icons'
 
       index=0
       currentIndex=0
@@ -106,7 +113,7 @@ class DlgConfig:
          if op==self.GetOperator():
             currentIndex = index
          index += 1
-#      self.comboop.setStyleSheet("padding: 2px")
+      self.comboop.setIconSize(QtCore.QSize(48, 48))
       self.comboop.setCurrentIndex(currentIndex)
       hLayoutCombo.addWidget(operateur)
       hLayoutCombo.addWidget(self.comboop)
