@@ -10,20 +10,20 @@ from DebugLog import DebugLog
 class QonsoExtractorSFR(QonsoExtractor):
    def __init__(self):
       DebugLog("QonsoExtractorSFR::init")
-      
+
       QonsoExtractor.__init__(self)
-      
+
       # URL de la page d'info conso
-      self.urlconso = "https://monprofil.sfr.fr/monprofilWEBV5/Accueil?acces=enc"
-      
+      self.urlconso = "https://monprofil.sfr.fr/monprofilWEBV5/Accueil?acces=enc&sfrintid=HP_ajax_compte_txt_conso"
+
       # URL présentant le formulaire pour la connection au compte
-      self.urlbeforeAuth = "https://www.sfr.fr/cas/login?domain=mon-compte"
-      
-      # URL où on envoie la requête POST pour l'authentification, en général, elle est dans le form 
+      self.urlbeforeAuth = "http://www.sfr.fr/cas/login?domain=mon-compte"
+
+      # URL où on envoie la requête POST pour l'authentification, en général, elle est dans le form
       self.urlAuth = "https://www.sfr.fr/cas/login?domain=mon-compte&service=https%3A%2F%2Fwww.sfr.fr%2Fj_spring_cas_security_check"
-      
+
       self.hostname = "www.sfr.fr"
-      
+
    def Authenticate(self):
       DebugLog("QonsoExtractorSFR::Authenticate")
       self.SetStatus('INFO', 'Authentification...')
@@ -33,39 +33,42 @@ class QonsoExtractorSFR(QonsoExtractor):
       # Mettre ici les paramètres du formulaire (login, password, champs cachés)
       params.addQueryItem("username", self.login)
       params.addQueryItem("password", self.password)
-      params.addQueryItem("internal", "W")
-      #
-      
+      params.addQueryItem("loginTicket", self.ticket)
+
       self.PostRequest(params)
-      
+
    def DoReadResponse(self, reply):
       DebugLog("QonsoExtractorSFR::DoReadResponse")
-      
+
       request = QNetworkRequest()
       page = QtWebKit.QWebPage()
       frame = page.currentFrame()
 
       # Phase d'initialisation, on va extraire 'idCorrelation', et on lance l'authentification avec
       DebugLog("authentication=="+self.authentication)
-      
+
       if self.authentication=='Init':
+         html = reply.readAll()
+         frame.setHtml(str(html))
+         self.ticket = frame.findFirstElement('input[name=loginTicket]').attribute('value')
+
          self.authentication = 'InProgress'
          self.Authenticate()
-      
+
       # Authentification en cours, on récupère la page de redirection, et on fait une redirection
       elif self.authentication == 'InProgress':
          html = str( reply.readAll() )
-         
+
          if not self.CheckForErrors(html):
             # pas d'erreur, c'est Lesieur, on peut charger la page des consommations
-            request.setUrl( QtCore.QUrl(self.urlconso) ) 
+            request.setUrl( QtCore.QUrl(self.urlconso) )
             self.authentication = 'Done'
             self.manager.get(request)
-      
+
    def CheckForErrors(self, html):
       r = re.compile('<p class="error">\s*<span>(.+?)<.*?</p>', re.DOTALL)
       res = r.search(html)
-      
+
       if res:
          DebugLog("Erreur trouvée : "+str(res.groups()) )
 
@@ -97,15 +100,17 @@ class QonsoExtractorSFR(QonsoExtractor):
          DebugLog("voixMax2 = "+res.group(3))
          DebugLog("forfait2 = "+res.group(2))
       else:
-         r = re.compile('votre [Ff]orfait.*?"(.*?)".*?[Vv]ous avez un [Ff]orfait .+?%s et vous avez consomm.*?%s de communication'%(self.hmReS,self.hmReS), re.DOTALL)
+         r = re.compile('votre [Ff]orfait.*?"(.*?)"', re.DOTALL)
+         r2 = re.compile('[Vv]ous avez un [Ff]orfait .+?%s et vous avez consomm.*?%s de communication'%(self.hmReS,self.hmReS), re.DOTALL)
          res = r.search(html)
+         res2 = r2.search(html)
          if res:
             self.model.SetForfait( res.group(1) )
-            self.model.SetConsoVoixMax( res.group(2) )
-            self.model.SetConsoVoix( res.group(3) )
+            self.model.SetConsoVoixMax( res2.group(1) )
+            self.model.SetConsoVoix( res2.group(2) )
             DebugLog("forfait = "+res.group(1))
             DebugLog("voix1 = "+res.group(1))
-            DebugLog("voixMax1 = "+res.group(3))
+            DebugLog("voixMax1 = "+res2.group(2))
 
       # Voix Supp
       DebugLog("\n____________________________________\nVoix Supp\n")
@@ -127,8 +132,8 @@ class QonsoExtractorSFR(QonsoExtractor):
             DebugLog("voixSuppMax = "+voixSuppMax)
             self.model.SetConsoVoixSuppMax( voixSuppMax+"00" )
             self.model.SetConsoVoixSupp( res.group(1), invert=True )
-      
-            
+
+
       # Date de dernière communication
       DebugLog("\n_____________________________________\nDerniere communication\n")
       DebugLog("-------------------------------------\n")
@@ -140,7 +145,7 @@ class QonsoExtractorSFR(QonsoExtractor):
          time = "%sh%.2d" % ( res.group(2), int(res.group(3)) )
          self.model.lastTime = "Ma consommation au "+date + " &agrave; "+ time
          DebugLog("last="+self.model.lastTime)
-         
+
       # Date de prochaine facture
       DebugLog("\n____________________________________\nProchaine facture\n")
       DebugLog("------------------------------------\n")
@@ -149,7 +154,7 @@ class QonsoExtractorSFR(QonsoExtractor):
          self.model.facture = "Prochaine facture : "+res.group(1)
          self.model.facture = self.model.facture.replace("\n", " ").replace("\r", "")
          DebugLog("facture="+self.model.facture)
-         
+
       # Report des minutes
       DebugLog("\n_____________________________________\nReport des minutes\n")
       DebugLog("-------------------------------------\n")
