@@ -11,6 +11,10 @@ def CreateExtractor(op):
    if op=="SFR":
       import QonsoExtractorSFR
       return QonsoExtractorSFR.QonsoExtractorSFR()
+
+   if op=="Universal Mobile": 
+      import QonsoExtractorUniversalMobile
+      return QonsoExtractorUniversalMobile.QonsoExtractorUniversalMobile()
       
    raise RuntimeError(u'Opérateur "%s" non supporté' % op)
          
\ No newline at end of file
