@@ -244,8 +244,8 @@ class QonsoView(QtGui.QMainWindow):
       else:
          self.SetText(self.statusLabel[0], "#269CCA", 16, context)
          self.statusLabel[1].setValue( self.extractor.GetProgress() )
-         time.sleep(0.005)
-         self.update()
+         #time.sleep(1)
+         #self.update()
          
       if self.labels.has_key('compte') and self.model.GetLastTime():
          self.SetText(self.labels['compte'][0], "#269CCA", 16, self.model.GetLastTime()+
@@ -304,6 +304,7 @@ class QonsoView(QtGui.QMainWindow):
                self.extractor.datasExtracted = False 
       self.firstDisplay = True
       self.UpdateConsoText()
+      event.accept()
       
    def closeEvent(self, event):
       self.config.WriteConfig()
